@@ -1,5 +1,8 @@
+import re
 from collections import OrderedDict
 
+from django.utils.text import capfirst
+
 
 def sorted_dict(d: dict):
     """
@@ -23,20 +26,36 @@ def choices_label(choices: tuple, value) -> str:
     return ''
 
 
-def _dict_to_html_r(data: dict, margin: str='') -> str:
+def _dict_to_html_format_key(k: str):
+    if k.startswith('@'):
+        k = k[1:]
+    k = k.replace('_', ' ')
+    k = re.sub(r'((?<=[a-z])[A-Z]|(?<!\A)[A-Z](?=[a-z]))', r' \1', k)
+    parts = k.split(' ')
+    out = [capfirst(parts[0].strip())]
+    for p in parts[1:]:
+        p2 = p.strip().lower()
+        if p2:
+            out.append(p2)
+    return ' '.join(out)
+
+
+def _dict_to_html_r(data: dict, margin: str = '') -> str:
     if not isinstance(data, dict):
         return '{}{}\n'.format(margin, data)
     out = ''
     for k, v in sorted_dict(data).items():
         if isinstance(v, dict):
-            out += '{}{}:\n'.format(margin, k)
-            out += _dict_to_html_r(v, margin+'    ')
+            out += '{}{}:\n'.format(margin, _dict_to_html_format_key(k))
+            out += _dict_to_html_r(v, margin + '    ')
+            out += '\n'
         elif isinstance(v, list):
             for v2 in v:
-                out += '{}{}:\n'.format(margin, k)
-                out += _dict_to_html_r(v2, margin+'    ')
+                out += '{}{}:\n'.format(margin, _dict_to_html_format_key(k))
+                out += _dict_to_html_r(v2, margin + '    ')
+            out += '\n'
         else:
-            out += '{}{}: {}\n'.format(margin, k, v)
+            out += '{}{}: {}\n'.format(margin, _dict_to_html_format_key(k), v)
     return out
 
 
