@@ -4,16 +4,20 @@ from io import StringIO
 from django.http import HttpResponse, FileResponse, Http404
 from django.utils.translation import ugettext as _
 
+from jutil.format import format_xml
+
 
 class FileSystemFileResponse(FileResponse):
     """
     File system download HTTP response.
     :param full_path: Full path to file
+    :param filename: Filename (optional) passed to client. Defaults to basename of the full path.
     """
-    def __init__(self, full_path: str, **kw):
-        filename = os.path.basename(full_path)
+    def __init__(self, full_path: str, filename: str = '', **kw):
         if not os.path.isfile(full_path):
             raise Http404(_("File {} not found").format(full_path))
+        if not filename:
+            filename = os.path.basename(full_path)
         content_type = mimetypes.guess_type(filename)[0]
         super().__init__(open(full_path, 'rb'), **kw)
         self['Content-Type'] = content_type
@@ -43,3 +47,23 @@ class CsvFileResponse(HttpResponse):
         buf = f.getvalue().encode('utf-8')
         super().__init__(content=buf, content_type='text/csv', **kw)
         self['Content-Disposition'] = 'attachment;filename="{0}"'.format(filename)
+
+
+class FormattedXmlFileResponse(HttpResponse):
+    def __init__(self, filename: str):
+        from jutil.format import format_xml_file
+        content = format_xml_file(filename)
+        super().__init__(content)
+        self['Content-Type'] = 'application/xml'
+        self['Content-Length'] = len(content)
+        self['Content-Disposition'] = "attachment; filename={}".format(os.path.basename(filename))
+
+
+class FormattedXmlResponse(HttpResponse):
+    def __init__(self, content: bytes, filename: str):
+        from jutil.format import format_xml_file
+        content = format_xml(content)
+        super().__init__(content)
+        self['Content-Type'] = 'application/xml'
+        self['Content-Length'] = len(content)
+        self['Content-Disposition'] = "attachment; filename={}".format(os.path.basename(filename))
